@@ -32,7 +32,7 @@
  * str_len -- determine length of string.
  * This is exactly equal to POSIX strlen(3).
  */
-size_t str_len(const char *s)
+str_size_t str_len(const char *s)
 {
     register char *t;
 
@@ -49,7 +49,7 @@ size_t str_len(const char *s)
  * This is inspired by POSIX strncpy(3), but the source and target
  * and overlap and the the target is always NUL-terminated.
  */
-char *str_copy(char *as, const char *at, size_t n)
+char *str_copy(char *as, const char *at, str_size_t n)
 {
     register char *s;
     register const char *t;
@@ -222,8 +222,8 @@ int str_compare(const char *s1, const char *s2, str_size_t n, int mode)
         /* compare case sensitive */
         do {
             if (*s1 != *s2++) {
-                rv = ((*(const unsigned char *)s1 - 
-                       *(const unsigned char *)(s2 - 1)) < 0 ? -1 : +1);
+                rv = (((int)(*(const unsigned char *)s1) - 
+                       (int)(*(const unsigned char *)(s2 - 1))) < 0 ? -1 : +1);
                 break;
             }
             if (bWithLen)
