@@ -152,7 +152,7 @@ pattern_cache(
     int h;
     struct hash_entry *he, *che;
 
-    if ((he = malloc(sizeof(struct hash_entry))) == NULL)
+    if ((he = (struct hash_entry *)malloc(sizeof(struct hash_entry))) == NULL)
         return;
     if ((he->key = malloc(keylen)) == NULL) {
         free(he);
@@ -405,7 +405,7 @@ int str_parse(const char *string, const char *pattern, ...)
     cap_num = pcre_info(p_pcre, NULL, NULL);
     if (cap_num > 0) {
         cap_len = (cap_num+1)*3;
-        if ((cap_vec = malloc(cap_len*sizeof(int))) == NULL) {
+        if ((cap_vec = (int *)malloc(cap_len*sizeof(int))) == NULL) {
             if (!match_once) {
                 free(p_pcre);
                 free(p_pcre_extra);
